### Features

- pandas.DataFrame
- sqlalchemy orm C.R.U.D Bulk operations
- Django orm C.R.U.D Bulk operations

# pandas-orm

![](https://raw.githubusercontent.com/ilyashusterman/pandas-orm/master/source_docs/_static/logo.png)

![Readme Card](https://github-readme-stats.vercel.app/api/pin/?username=ilyashusterman&repo=pandas-orm)


**Table of Contents**

[TOCM]

[TOC]

#Documentation
----

[Documentation](https://ilyashusterman.github.io/pandas-orm/)

